export interface PageRange {
    /**
     * Page Number
     *
     * @description
     * Query Param: page
     *
     * Specifies the page to extract from multi-page input files (PDF, GIF, TIFF).
     *
     * Number is zero-based.
     *
     * @isInt
     * @minimum 0
     * @default 0
     * @examples [0]
     */
    page: number | undefined;
    /**
     * Page Count
     *
     * @description
     * Query Param: page-count
     *
     * Specifies the number of pages to extract from multi-page input files (PDF, GIF, TIFF).
     *
     * You may specify `-1` to extract all pages.
     *
     * @isInt
     * @minimum -1
     * @default 1
     * @examples [1]
     */
    pageCount: number | undefined;
}
export declare namespace PageRange {
    const defaultValue: PageRange;
}
